package com.muyu.system.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.muyu.common.core.utils.StringUtils;
import com.muyu.common.core.web.page.PageQueryModel;
import com.muyu.common.system.domain.SysLogininfor;
import com.muyu.system.domain.model.SysLogininforAddModel;
import com.muyu.system.domain.model.SysLogininforExportModel;
import com.muyu.system.domain.model.SysLogininforListModel;
import com.muyu.system.mapper.SysLogininforMapper;
import com.muyu.system.service.SysLogininforService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * 系统访问日志情况信息 服务层处理
 *
 * @author muyu
 */
@Service
public class SysLogininforServiceImpl extends ServiceImpl<SysLogininforMapper, SysLogininfor> implements SysLogininforService {

    private final SysLogininforMapper logininforMapper;

    @Autowired
    public SysLogininforServiceImpl(SysLogininforMapper logininforMapper) {
        this.logininforMapper = logininforMapper;
    }

    /**
     * 新增系统登录日志
     *
     * @param logininforAddModel 访问日志对象
     */
    @Override
    public void insertLogininfor (SysLogininforAddModel logininforAddModel) {
        SysLogininfor logininfor = SysLogininforAddModel.of(logininforAddModel);
        logininfor.setAccessTime(new Date());
        this.save(logininfor);
    }

    /**
     * 查询系统登录日志集合
     *
     * @param pageQueryModel 访问日志对象
     *
     * @return 登录记录集合
     */
    @Override
    public PageQueryModel<SysLogininforListModel> pageQuery(SysLogininforListModel pageQueryModel) {
        Page<SysLogininfor> page = this.page(pageQueryModel.buildPage(), new LambdaQueryWrapper<SysLogininfor>()
                .like(StringUtils.isNotEmpty(pageQueryModel.getIpaddr()), SysLogininfor::getIpaddr, pageQueryModel.getIpaddr())
                .eq(StringUtils.isNotEmpty(pageQueryModel.getStatus()), SysLogininfor::getStatus, pageQueryModel.getStatus())
                .like(StringUtils.isNotEmpty(pageQueryModel.getUserName()), SysLogininfor::getUserName, pageQueryModel.getUserName())
                .between(!ObjectUtil.hasNull(pageQueryModel.getBeginTime(),pageQueryModel.getEndTime()), SysLogininfor::getAccessTime, pageQueryModel.getBeginTime(), pageQueryModel.getEndTime()));
       return new PageQueryModel<>(){{
          setDataList(page.getRecords().stream()
                  .map(SysLogininforListModel::buildSysLogininforListModel)
                  .toList());
          setTotal(page.getTotal());
        }};
    }

    /**
     * 批量删除系统登录日志
     *
     * @param infoIds 需要删除的登录日志ID
     *
     * @return 结果
     */
    @Override
    public void deleteLogininforByIds (List<Long> infoIds) {
        this.removeByIds(infoIds);
    }

    /**
     * 清空系统登录日志
     */
    @Override
    public void cleanLogininfor () {
        logininforMapper.cleanLogininfor();
    }

    /**
     * 导出数据
     * @param exportModel 数据导出模型
     * @return 返回结果
     */
    @Override
    public List<SysLogininfor> exportQuery(SysLogininforExportModel exportModel) {
        LambdaQueryWrapper<SysLogininfor> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.like(StringUtils.isNotEmpty(exportModel.getIpaddr()), SysLogininfor::getIpaddr, exportModel.getIpaddr());
        queryWrapper.eq(StringUtils.isNotEmpty(exportModel.getStatus()), SysLogininfor::getStatus, exportModel.getStatus());
        queryWrapper.like(StringUtils.isNotEmpty(exportModel.getUserName()), SysLogininfor::getUserName, exportModel.getUserName());
        queryWrapper.between(!ObjectUtil.hasNull(exportModel.getBeginTime(),exportModel.getEndTime()), SysLogininfor::getAccessTime, exportModel.getBeginTime(), exportModel.getEndTime());
        return this.list(queryWrapper);
    }
}
